build abstract method

Widget build(
  1. I wm
)

Describes the part of the user interface represented by this widget, based on the state of the WidgetModel passed to the wm argument.

There is no access to the BuildContext in this method, because all needed in this method should be provided by WidgetModel which has direct access to the BuildContext. It is uncommon to use BuildContext here, possibly in this case you need to improve implementation of the WidgetModel. But BuildContext CAN be used in all builder functions and all widgets used here.

Implementation

Widget build(I wm);